@@ -32,11 +32,12 @@
 #include <gtk/gtkwidget.h>
 #include <gtk/gtkliststore.h>
 #include <gtk/gtktooltips.h>
+#include "e-contact-entry.h"
 
 typedef struct _EvoLookupApplet {
   /* GConf */
   GConfClient *gconf_client;
-  guint source_notify_id;
+  ESourceList *source_list;
 
   /* Widgets */
   GtkWidget *applet_widget;
